SystemOrganization addCategory: #GODCallTests!

TestCase subclass: #GCConfSearchCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCConfSearchCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 12:25'!
testParse
	|fileData mockPath conferences crawler conference1 conference2 keywords|
	mockPath := '/home/camila/Dropbox/POO 2014/confsearchpage.html'.	
      fileData := (StandardFileStream fileNamed: mockPath ) contentsOfEntireFile.
	crawler := GCConfSearchCrawler new.
	conferences :=  crawler parse: fileData.
	self assert: (conferences size)  = 32.
	
	conference1 := conferences at: 2.
	conference2 := conferences at: 3.

	self assert: conference1 acronym = 'flairs'.
	self assert: conference1 name = 'The Florida AI Research Society (FLAIRS)'.
	self assert: conference1 url = 'http://www.flairs-28.info/'.
	self assert: (conference1 importantDates) deadlineDate = '17 Nov 14'.
	self assert: (conference1 importantDates) startDate = '18 May 15'.
	self assert: (conference1 importantDates) endDate = '20 May 15'.
	self assert: (conference1 venue) city = 'Hollywood'.
	self assert: (conference1 venue) country = 'USA'. 
	keywords := conference1 keywords.
	self assert: keywords size = 7.
	self assert: (keywords includes: 'knowledge').
	self assert: (keywords includes: 'learning').
	self assert: (keywords includes: 'reasoning').
	self assert: (keywords includes: 'based').
	self assert: (keywords includes: 'using').
	self assert: (keywords includes: 'tutoring').
	self assert: (keywords includes: 'neural').
		

	self assert: conference2 acronym = 'aia'.
	self assert: conference2 name = 'Artificial Intelligence and Applications'.
	self assert: conference2 url = 'http://www.iasted.org/conferences/home-793.html'.
	self assert: (conference2 importantDates) deadlineDate = '03 Dec 12'.
	self assert: (conference2 importantDates) startDate = '11 Feb 13'.
	self assert: (conference2 importantDates) endDate = '13 Feb 13'.
	self assert: (conference2 venue) city = 'Innsbruck'.
	self assert: (conference2 venue) country = 'Austria'. 
	keywords := conference2 keywords.
	self assert: keywords size = 8.
	self assert: (keywords includes: 'neural').
	self assert: (keywords includes: 'genetic').
	self assert: (keywords includes: 'using').
	self assert: (keywords includes: 'artificial').
	self assert: (keywords includes: 'fuzzy').
	self assert: (keywords includes: 'algorithm').	
	self assert: (keywords includes: 'network').
	self assert: (keywords includes: 'networks').
	! !

!GCConfSearchCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 01:17'!
testParseVenue
	|locationString venue crawler|
	crawler := GCConfSearchCrawler new.
	locationString := 'Spain, Tenerife'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = 'Tenerife'.
	self assert: venue country = 'Spain'.

	locationString := 'Spain,'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = nil.
	self assert: venue country = 'Spain'.

	locationString := 'USA, Hollywood, Florida, USA'.
	venue := crawler parseVenue: locationString.
	self assert: venue city = 'Hollywood'.
	self assert: venue country = 'USA'.! !

TestCase subclass: #GCConferenceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 10/18/2014 17:02'!
testFromSpreadhsheet
	"test if given a spreadsheet with conference data it is converted to GODConferences correctly"
	 |spreadsheet godConferencesCollection|
	"when tested, we didnt get a valid spreadsheet"
	spreadsheet := GCConference from: (SSSpreadsheetData fromCSV: '/home/camila/Dropbox/POO 2014/conferencesMock.csv').
	godConferencesCollection := GCConference from: spreadsheet.
	
	godConferencesCollection do: [ :godConference | 
		self assert: godConference getName = 'Artificial Intelligence and Applications'
	]! !

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 10/18/2014 15:20'!
testGenerateGODConferencesFromSpreadsheet
	"cant remove it..."! !

!GCConferenceTest methodsFor: 'testing' stamp: 'cms 10/18/2014 16:41'!
testToSpreedsheet
	|collection conference spreadsheet
	sheet rows
	conferenceName conferenceAcronym conferenceUrl
	conferenceKeywords conferenceStartDate conferenceEndDate conferenceDeadlineDate 
	conferenceCity conferenceCountry|


	conference := GCConference new.
	conferenceAcronym := 'aia'.
	conferenceName := 'Artificial Intelligence and Applications'.
	conferenceKeywords := Set new.
	conferenceKeywords add: 'neural'; add: 'genetic'.
	conferenceUrl:= 'http://conferences'.
	conferenceDeadlineDate := '24 mar 14'.
	conferenceStartDate := '20 abr 14'.
	conferenceEndDate := '25 abr 14'.
	conferenceCity := 'Holywood'.
	conferenceCountry := 'USA'.

	conference acronym: conferenceAcronym.	
	conference name: conferenceName.
	conference url: conferenceUrl.
	conference keywords: conferenceKeywords.
	conference importantDates: GCImportantDates new.
	conference importantDates deadlineDate: conferenceDeadlineDate.	
	conference importantDates startDate: conferenceStartDate.	
	conference importantDates endDate: conferenceEndDate.	
	conference venue: GCVenue new.
	conference venue city: conferenceCity.
	conference venue country: conferenceCountry.
	collection := OrderedCollection new.
	collection add: conference.
	spreadsheet  := GCConference asSpreadsheet: collection.
	sheet := spreadsheet getSheet: 1.
	rows := sheet rows.
	rows do: [:row |
		self assert: (row getCell: 'acronym') = conferenceAcronym.
		self assert: (row getCell: 'name') = conferenceName.
		self assert: (row getCell: 'keywords') = conferenceKeywords.
		self assert: (row getCell: 'url') = conferenceUrl.
		self assert: (row getCell: 'city') = conferenceCity.
		self assert: (row getCell: 'country') = conferenceCountry.
		self assert: (row getCell: 'deadlineDate') = conferenceDeadlineDate.
		self assert: (row getCell: 'startDate') = conferenceStartDate.
		self assert: (row getCell: 'endDate') = conferenceEndDate.
	].
	
	
	! !

TestCase subclass: #GCSourceCrawlerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GCSourceCrawlerTest class methodsFor: 'filtering' stamp: 'pfsm 10/16/2014 17:26'!
filter: aText startMark: startMark endMark: endMark
	"comment stating purpose of message"

	| regex prefix suffix matches|

	prefix:= startMark copyReplaceAll: ':' with: '\:'.
	prefix := prefix copyReplaceAll: '?' with: '\?'.
	suffix:= endMark copyReplaceAll: ':' with: '\:'.
	suffix := suffix copyReplaceAll: '?' with: '\?'.

	regex:= (prefix,'(\w|\s|[-]|[.]|[:]|[/]|[,]|[?])*',suffix) asRegexIgnoringCase.

	matches := regex matchesIn: aText collect: [:match | 	match:= match copyReplaceAll: startMark with: String empty.
																					match copyReplaceAll: endMark with: String empty.
																	].

	^matches.! !

!GCSourceCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 11:49'!
parseWikiCfpTest
"i can't remove it :("! !

!GCSourceCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 11:48'!
testParseWikiCfp
	"categoryUrl is the general url to the webpage of WikiCFP containing the conferences of a given category. This method returns a list of GCConferences whose attributes are extracted from categoryUrl"
	| html filteredStrings acronymAndEditionSMark acronymAndEditionEMark nameSMark nameEMark urlSMark urlEMark startAndDeadlineSMark startAndDeadlineEMark endSMark endEMark cityAndCountrySMark cityAndCountryEMark categoriesSMark categoriesEMark conference conferenceImportantDates conferenceVenue conferenceCategories rightConference|

	html := '<span property="dc:title" content="LICS 2013"></span><span property="dc:description" content="28th Annual ACM/IEEE Symposium on Logic In Computer Science"></span><span property="dc:source" content="http://www2.informatik.hu-berlin.de/lics/lics13/"></span><span property="v:startDate" content="2013-06-25T00:00:00"></span><span property="v:startDate" content="2013-01-07T00:00:00"><span property="v:startDate" content="2013-01-14T00:00:00"><span property="v:startDate" content="2013-03-22T00:00:00"><span property="v:startDate" content="2013-04-26T00:00:00"><span property="v:endDate" content="2013-06-28T23:59:59"></span>"v:locality" content="New Orleans, USA"><a href="../call?conference=logic">logic</a>&nbsp;&nbsp; <a href="../call?conference=theoretical computer science"'.

	acronymAndEditionSMark :='"dc:title" content="'.
	acronymAndEditionEMark :='"'.
	nameSMark :='"dc:description" content="'.
	nameEMark :='"'.
	urlSMark :='"dc:source" content="'.
	urlEMark :='"'.
	startAndDeadlineSMark :='"v:startDate" content="'.
	startAndDeadlineEMark :='T'.
	endSMark :='"v:endDate" content="'.
	endEMark :='T'.
	cityAndCountrySMark :='"v:locality" content="'.
	cityAndCountryEMark :='"'.
	categoriesSMark:='<a href="../call?conference='.
	categoriesEMark:='"'.	

	filteredStrings := String empty.


	conference := GCConference new.
											
	"filteredStrings := FILTConferenceFilter filter: (pageData content) startMark: acronymAndEditionSMark endMark: acronymAndEditionEMark."
	filteredStrings := self filter: html startMark: acronymAndEditionSMark endMark: acronymAndEditionEMark.
	filteredStrings := (filteredStrings at:1) findTokens: String space.
	conference acronym: (filteredStrings at:1).
	conference edition: (filteredStrings at:2).

	"filteredStrings := FILTConferenceFilter filter: (pageData content) startMark: nameSMark endMark: nameEMark."
	filteredStrings := GCSourceCrawlerTest filter: html startMark: nameSMark endMark: nameEMark.
	conference name: (filteredStrings at:1).

	"filteredStrings := FILTConferenceFilter filter: (pageData content) startMark: urlSMark endMark: urlEMark."
	filteredStrings := GCSourceCrawlerTest filter: html startMark: urlSMark endMark: urlEMark.
	conference url: ((filteredStrings at:1) asUrl).

	conferenceImportantDates := GCImportantDates new.
	"filteredStrings := FILTConferenceFilter filter: (pageData content) startMark: startAndDeadlineSMark endMark: startAndDeadlineEMark."
	filteredStrings := GCSourceCrawlerTest filter: html  startMark: startAndDeadlineSMark endMark: startAndDeadlineEMark.
	conferenceImportantDates startDate: ((filteredStrings at:1) asDate).
	conferenceImportantDates deadlineDate: ((filteredStrings at:2) asDate).

	"filteredStrings := FILTConferenceFilter filter: (pageData content) startMark: endSMark endMark: endEMark."
	filteredStrings := GCSourceCrawlerTest filter: html startMark: endSMark endMark: endEMark.
	conferenceImportantDates endDate: ((filteredStrings at:1) asDate).

	conferenceVenue := GCVenue new.
	"filteredStrings := FILTConferenceFilter filter: (pageData content) startMark: cityAndCountrySMark endMark: cityAndCountryEMark."
	filteredStrings := GCSourceCrawlerTest filter: html startMark: cityAndCountrySMark endMark: cityAndCountryEMark.
	filteredStrings := (filteredStrings at:1) findTokens: ','.
	"conferenceVenue city: ((filteredStrings at: 1) copyReplaceAll: ',' with: String empty)."
	conferenceVenue city: (filteredStrings at: 1) .
	"sometimes there is only the city of the event"
	conferenceVenue country: ((filteredStrings size > 1) 
												ifTrue: [(filteredStrings at: 2) allButFirst:1] 
												ifFalse:[nil]).

	conferenceCategories := Set new.
	"filteredStrings := FILTConferenceFilter filter: (pageData content) startMark: categoriesSMark endMark: categoriesEMark."
	filteredStrings := GCSourceCrawlerTest filter: html startMark: categoriesSMark endMark: categoriesEMark.
	filteredStrings do:[:category | conferenceCategories add: (category asLowercase)].


	conference importantDates: conferenceImportantDates.
	conference venue: conferenceVenue.
	conference categories: conferenceCategories.
							

	"Now we create a conference2 object containing all the correct attributes, and we compare it to the conference object obtained from the parser"
	rightConference := GCConference new.
	rightConference acronym:'LICS'.
	rightConference name:'28th Annual ACM/IEEE Symposium on Logic In Computer Science'.
	rightConference edition: '2013'.
	rightConference url: 'http://www2.informatik.hu-berlin.de/lics/lics13/' asUrl.
	conferenceImportantDates := GCImportantDates from: '2013-06-25' asDate to: '2013-06-28' asDate deadline: '2013-01-07' asDate.
	conferenceVenue:= GCVenue city: 'New Orleans' country:'USA'.
	conferenceCategories:= Set with:  'theoretical computer science' with: 'logic'.

	rightConference importantDates: conferenceImportantDates.
	rightConference venue: conferenceVenue.
	rightConference categories: conferenceCategories.

^ (conference = rightConference).! !

!GCSourceCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 11:49'!
testWikiCfpCrawler
	"method for testing GCWikiCfpCrawler>>crawl:"

	| conferenceList  rightConference conferenceImportantDates conferenceVenue conferenceCategories |
	
	conferenceList := (GCWikiCfpCrawler new) crawl: String empty.

"Now we create a conference object containing all the correct attributes, then we compare it to the conference object obtained from method crawl:"
	rightConference := GCConference new.
	rightConference acronym:'LICS'.
	rightConference name:'28th Annual ACM/IEEE Symposium on Logic In Computer Science'.
	rightConference edition: '2013'.
	rightConference url: 'http://www2.informatik.hu-berlin.de/lics/lics13/' asUrl.
	conferenceImportantDates := GCImportantDates from: '2013-06-25' asDate to: '2013-06-28' asDate deadline: '2013-01-07' asDate.
	conferenceVenue:= GCVenue city: 'New Orleans' country:'USA'.
	conferenceCategories:= Set with:  'theoretical computer science' with: 'logic'.

	rightConference importantDates: conferenceImportantDates.
	rightConference venue: conferenceVenue.
	rightConference categories: conferenceCategories.

^ (conferenceList includes: rightConference).! !

!GCSourceCrawlerTest methodsFor: 'testing' stamp: 'cms 10/18/2014 11:49'!
wikiCfpCrawlerTest! !

TestCase subclass: #GODCallTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODCallTests'!

!GODCallTest methodsFor: 'testing' stamp: 'cms 9/28/2014 12:45'!
testUserSearch
	"emulate a user's search"

	| searchFilter godCall page|
"	searchFilter := GCSearchFilter new.
	searchFilter searchKey: 'algorithms'.
	searchFilter category: 'theory of computation'.
	searchFilter startDate: (Date year:2015 month: 1 day: 1).
	searchFilter endDate: (Date year:2015 month: #December  day: 1)."

	searchFilter := (GCSearchFilter search: 'algorithms' in: 'theory of computation' from: (Date year:2015 month: 1 day: 1) to: (Date year:2015 month: #December  day: 1)).

	"call submitForm using searchFilter. Perhaps, this should be a static method."
	godCall := GODCall new.
	page := godCall submitForm: searchFilter.

	"TODO: assert other characteristics it must have"
	self assert: (page isKindOf: GODData)! !
